@@ -4,9 +4,8 @@
 from pyrseas.testutils import DatabaseToMapTestCase
 from pyrseas.testutils import InputMapToSqlTestCase, fix_indent
 
-CREATE_STMT = "CREATE OPERATOR FAMILY of1 USING btree"
-DROP_STMT = "DROP OPERATOR FAMILY IF EXISTS of1 USING btree"
-COMMENT_STMT = "COMMENT ON OPERATOR FAMILY of1 USING btree IS " \
+CREATE_STMT = "CREATE OPERATOR FAMILY sd.of1 USING btree"
+COMMENT_STMT = "COMMENT ON OPERATOR FAMILY sd.of1 USING btree IS " \
     "'Test operator family of1'"
 
 
@@ -18,12 +17,12 @@ class OperatorFamilyToMapTestCase(DatabaseToMapTestCase):
     def test_map_operfam(self):
         "Map an operator family"
         dbmap = self.to_map([CREATE_STMT])
-        assert dbmap['schema public']['operator family of1 using btree'] == {}
+        assert dbmap['schema sd']['operator family of1 using btree'] == {}
 
     def test_map_operfam_comment(self):
         "Map an operator family comment"
         dbmap = self.to_map([CREATE_STMT, COMMENT_STMT])
-        assert dbmap['schema public']['operator family of1 using btree'][
+        assert dbmap['schema sd']['operator family of1 using btree'][
             'description'] == 'Test operator family of1'
 
 
@@ -33,12 +32,12 @@ class OperatorFamilyToSqlTestCase(InputMapToSqlTestCase):
     def test_create_operfam(self):
         "Create an operator family"
         inmap = self.std_map()
-        inmap['schema public'].update({'operator family of1 using btree': {}})
+        inmap['schema sd'].update({'operator family of1 using btree': {}})
         sql = self.to_sql(inmap)
         assert fix_indent(sql[0]) == CREATE_STMT
 
     def test_create_operfam_in_schema(self):
-        "Create an operator family within a non-public schema"
+        "Create an operator family within a non-default schema"
         inmap = self.std_map()
         inmap.update({'schema s1': {'operator family of1 using btree': {}}})
         sql = self.to_sql(inmap, ["CREATE SCHEMA s1"])
@@ -48,12 +47,12 @@ class OperatorFamilyToSqlTestCase(InputMapToSqlTestCase):
     def test_drop_operfam(self):
         "Drop an existing operator family"
         sql = self.to_sql(self.std_map(), [CREATE_STMT], superuser=True)
-        assert sql == ["DROP OPERATOR FAMILY of1 USING btree"]
+        assert sql == ["DROP OPERATOR FAMILY sd.of1 USING btree"]
 
     def test_operfam_with_comment(self):
         "Create an operator family with a comment"
         inmap = self.std_map()
-        inmap['schema public'].update({'operator family of1 using btree': {
+        inmap['schema sd'].update({'operator family of1 using btree': {
             'description': 'Test operator family of1'}})
         sql = self.to_sql(inmap)
         assert fix_indent(sql[0]) == CREATE_STMT
@@ -62,7 +61,7 @@ class OperatorFamilyToSqlTestCase(InputMapToSqlTestCase):
     def test_comment_on_operfam(self):
         "Create a comment for an existing operator family"
         inmap = self.std_map()
-        inmap['schema public'].update({'operator family of1 using btree': {
+        inmap['schema sd'].update({'operator family of1 using btree': {
             'description': 'Test operator family of1'}})
         sql = self.to_sql(inmap, [CREATE_STMT], superuser=True)
         assert sql == [COMMENT_STMT]
@@ -71,16 +70,16 @@ class OperatorFamilyToSqlTestCase(InputMapToSqlTestCase):
         "Drop a comment on an existing operator family"
         stmts = [CREATE_STMT, COMMENT_STMT]
         inmap = self.std_map()
-        inmap['schema public'].update({'operator family of1 using btree': {}})
+        inmap['schema sd'].update({'operator family of1 using btree': {}})
         sql = self.to_sql(inmap, stmts, superuser=True)
-        assert sql == ["COMMENT ON OPERATOR FAMILY of1 USING btree IS NULL"]
+        assert sql == ["COMMENT ON OPERATOR FAMILY sd.of1 USING btree IS NULL"]
 
     def test_change_operfam_comment(self):
         "Change existing comment on a operator"
         stmts = [CREATE_STMT, COMMENT_STMT]
         inmap = self.std_map()
-        inmap['schema public'].update({'operator family of1 using btree': {
+        inmap['schema sd'].update({'operator family of1 using btree': {
             'description': 'Changed operator family of1'}})
         sql = self.to_sql(inmap, stmts, superuser=True)
-        assert sql == ["COMMENT ON OPERATOR FAMILY of1 USING btree IS "
+        assert sql == ["COMMENT ON OPERATOR FAMILY sd.of1 USING btree IS "
                        "'Changed operator family of1'"]
